@@ -1,11 +1,6 @@
-red = "red"
-yellow = "yellow"
-green = "green"
-cyan = "cyan"
-blue = "blue"
-magenta = "magenta"
-black = "black"
-white = "white"
+'''
+Color Module for the BD103 Package
+'''
 
 def print(text, color):
     if color == "reset":
